@@ -4,6 +4,7 @@ import logging
 import os
 import tempfile
 import threading
+import taskthread
 from Queue import Queue
 from functools import wraps
 
@@ -34,9 +35,9 @@ def require_started_batch(func):
     return inner_func
 
 
-class QueryThread(threading.Thread):
+class Query(object):
     """
-    Thread object which will execute the ``COPY`` query.
+    An object that executes the ``COPY`` query for batch loading.
 
     :param cursor:
         A :py:mod:`!pyodbc` cursor object.
@@ -62,22 +63,21 @@ class QueryThread(threading.Thread):
     """
 
     def __init__(
-            self, cursor, sql_query_str, semaphore_obj, fifo_path, exc_queue):
-        super(QueryThread, self).__init__()
+            self, cursor, sql_query_str, fifo_path, exc_queue):
+        super(Query, self).__init__()
         self.cursor = cursor
         self.sql_query_str = sql_query_str
-        self.semaphore_obj = semaphore_obj
         self.exc_queue = exc_queue
         self.fifo_path = fifo_path
 
-    def run(self):
+    def run_query(self):
         """
         Handle executing the SQL query.
 
-        This method will be called when starting this thread.
+        This method is intended to be called on a task_thread.
 
         """
-        logger.debug('Thread started with SQL statement: {0}'.format(
+        logger.debug('Query started with SQL statement: {0}'.format(
             self.sql_query_str))
         try:
             self.cursor.execute(self.sql_query_str)
@@ -92,8 +92,7 @@ class QueryThread(threading.Thread):
             for line in codecs.open(self.fifo_path, 'r', 'utf-8'):
                 pass
 
-        logger.debug('Thread done')
-        self.semaphore_obj.release()
+        logger.debug('Query done')
 
 
 class VerticaBatch(object):
@@ -111,7 +110,8 @@ class VerticaBatch(object):
             column_list=['column_1', 'column_2'],
             copy_options={
                 'DELIMITER': ',',
-            }
+            },
+            multi_batch=False
         )
 
         row_list = [
@@ -134,16 +134,19 @@ class VerticaBatch(object):
         multiple times (for example after every 50000 records). Please note
         that after the first insert and after calling
         :py:meth:`~.VerticaBatch.commit`, the output of
-        :py:meth:`~.VerticaBatch.get_errors` will reflect the new serie of
+        :py:meth:`~.VerticaBatch.get_errors` will reflect the new series of
         inserts and thus not contain the "old" inserts.
 
     .. note:: Creating a new batch object will not create a lock on the target
         table. This will happen only after first insert.
 
-    .. note:: Although the batch object is automagically reusable, after a
-        :py:meth:`~.VerticaBatch.commit` the locks are realeased up to next
-        insert.
-
+    .. note:: If a batch is created with ``multi_batch = True``,
+        :py:meth:`~.VerticaBatch.close_batch` must be explicity called when
+        the batch resources should be closed. If ``multi_batch`` is set to
+        ``False``, :py:meth:`~.VerticaBatch.close_batch` need not be called.
+        In this case, while the batch is reusable, the system resources will
+        be realoccated uppon each :py:meth:`~.VerticaBatch.commit`, which
+        may not be desirable.
 
     :param table_name:
         A ``str`` representing the table name (including the schema) to write
@@ -178,6 +181,19 @@ class VerticaBatch(object):
         and their defaults, see :py:attr:`~.VerticaBatch.copy_options_dict`.
         *Optional*.
 
+    :param connection:
+        A ``pyodbc.Connection`` to use instead of opening a new connection. If
+        this parameter is supplied, ``odbc_kwargs`` may not be supplied.
+        Default: ``None``. *Optional*.
+
+    :param multi_batch:
+        A ``boolean`` to indicate if the batch should keep it's resources open
+        after a call to commit. If you plan to only call
+        :py:meth:`~.VerticaBatch.commit` one time, set this to false.
+        Otherwise, setting ``multi_batch=True`` will prevent the batch from
+        closing all of its resources.
+        Default: ``False``. *Optional*.
+
     """
     copy_options_dict = {
         'DELIMITER': ';',
@@ -205,30 +221,42 @@ class VerticaBatch(object):
             reconnect=True,
             analyze_constraints=True,
             column_list=[],
-            copy_options={}):
-        # make sure we are not logging any passwords :)
-        odbc_kwargs_copy = copy.deepcopy(odbc_kwargs)
-        if 'password' in odbc_kwargs_copy:
-            odbc_kwargs_copy['password'] = '*****'
-        logger.debug(
-            'Initializing VerticaBatch with odbc_kwargs={0}, table_name={1}, '
-            'column_list={2}'.format(
-                odbc_kwargs_copy, table_name, column_list))
+            copy_options={},
+            connection=None,
+            multi_batch=False):
+
+        if connection and odbc_kwargs:
+            raise ValueError("May only specify one of "
+                             "[connection, odbc_kwargs]")
 
         self._odbc_kwargs = odbc_kwargs
         self._table_name = table_name
         self._column_list = column_list
         self._analyze_constraints = analyze_constraints
         self.copy_options_dict.update(copy_options)
+        self._batch_initialized = False
+        self._multi_batch = multi_batch
 
         self._total_count = 0
         self._batch_count = 0
 
         self._in_batch = False
 
-        # setup db connection
-        self._connection = get_connection(
-            reconnect=reconnect, **self._odbc_kwargs)
+        if not connection:
+            # make sure we are not logging any passwords :)
+            odbc_kwargs_copy = copy.deepcopy(odbc_kwargs)
+            if 'password' in odbc_kwargs_copy:
+                odbc_kwargs_copy['password'] = '*****'
+            logger.debug(
+                'Initializing VerticaBatch with odbc_kwargs={0}, '
+                'table_name={1}, '
+                'column_list={2}'.format(
+                    odbc_kwargs_copy, table_name, column_list))
+            self._connection = get_connection(
+                reconnect=reconnect, **self._odbc_kwargs)
+        else:
+            self._connection = connection
+
         self._cursor = self._connection.cursor()
 
         # truncate table, if needed
@@ -242,6 +270,30 @@ class VerticaBatch(object):
         logger.info('Truncating table {0}'.format(self._table_name))
         self._cursor.execute('TRUNCATE TABLE {0}'.format(self._table_name))
 
+    def _initialize_batch(self):
+
+        self._query_exc_queue = Queue()
+
+        # create FIFO
+        self._fifo_path = os.path.join(tempfile.mkdtemp(), 'fifo')
+        os.mkfifo(self._fifo_path)
+
+        # create rejected file obj
+        if self.copy_options_dict['REJECTEDFILE']:
+            self._rejected_file_obj = tempfile.NamedTemporaryFile(bufsize=0)
+        self._query = Query(
+            self._cursor,
+            self._get_sql_lcopy_str(),
+            self._fifo_path,
+            self._query_exc_queue,
+        )
+
+        self._query_thread = taskthread.TaskThread(self._query.run_query)
+
+        # Start the thread so run_task can be called
+        self._query_thread.start()
+        self._batch_initialized = True
+
     def _start_batch(self):
         """
         Start the batch.
@@ -252,26 +304,10 @@ class VerticaBatch(object):
         """
         self._in_batch = True
         self._batch_count = 0
-        self._query_exc_queue = Queue()
+        if not self._batch_initialized:
+            self._initialize_batch()
 
-        # create FIFO
-        self._fifo_path = os.path.join(tempfile.mkdtemp(), 'fifo')
-        os.mkfifo(self._fifo_path)
-
-        # create rejected file obj
-        if self.copy_options_dict['REJECTEDFILE']:
-            self._rejected_file_obj = tempfile.NamedTemporaryFile(bufsize=0)
-
-        # setup query thread
-        self._query_thread_semaphore_obj = threading.Semaphore(0)
-        self._query_thread = QueryThread(
-            self._cursor,
-            self._get_sql_lcopy_str(),
-            self._query_thread_semaphore_obj,
-            self._fifo_path,
-            self._query_exc_queue,
-        )
-        self._query_thread.start()
+        self._query_thread.run_task()
 
         logger.debug('Opening FIFO')
         self._fifo_obj = codecs.open(self._fifo_path, 'w', 'utf-8')
@@ -283,25 +319,44 @@ class VerticaBatch(object):
         """
         End the batch.
 
-        This will remove the FIFO file and stop the :py:class:`.QueryThread`.
+        This waits for the current query to finish, and executes
+        close_batch if multi_batch is false.
 
         """
         ended_clean = True
 
         logger.debug('Closing FIFO')
+        # The Query task will stop when there is nothing writing to
+        # the fifo. This should force the current task to end.
         self._fifo_obj.close()
 
-        logger.debug('Waiting for thread to finish')
-        self._query_thread_semaphore_obj.acquire()
-        logger.debug('Thread finished')
+        logger.debug('Waiting for COPY Query to finish')
+        if not self._query_thread.join_task(2):
+            logger.warn('Error shutting down task thread!')
+        else:
+            logger.debug('Query task finished')
 
+        if not self._multi_batch:
+            ended_clean = self.close_batch() and ended_clean
+
+        self._in_batch = False
+        return ended_clean
+
+    def close_batch(self):
+        """
+        Close out the batch.
+
+        This will remove the FIFO file and stop the ``taskthread.TaskThread``.
+
+        """
+
+        ended_clean = True
         logger.debug('Terminating thread')
         self._query_thread.join(2)
         if self._query_thread.is_alive():
             ended_clean = False
             logging.error('Terminating thread timed out!')
 
-        self._in_batch = False
         os.remove(self._fifo_path)
         os.rmdir(os.path.dirname(self._fifo_path))
 
@@ -310,6 +365,7 @@ class VerticaBatch(object):
         if not self._query_exc_queue.empty():
             raise self._query_exc_queue.get()
 
+        self._batch_initialized = False
         return ended_clean
 
     def _get_num_rejected_rows(self):
@@ -403,6 +459,35 @@ class VerticaBatch(object):
 
         return output_str
 
+    def _single_list_to_string(self,
+                               value_list,
+                               suffix=None):
+        """
+        Convert a single ``iterable`` to a string that represents one item
+        in the batch.
+
+        :param value_list:
+            An ``iterable``. Each item represents one column value
+
+        :param suffix:
+            A ``string``. If specified, this character will be appended
+            to the resulting string.
+        """
+        enclosed_by = self.copy_options_dict['ENCLOSED BY']
+        escaped_enclosed_by = '\\%s' % enclosed_by
+        suffix = suffix if suffix else ''
+        delimiter = self.copy_options_dict['DELIMITER']
+
+        str_value_list = (
+            '%s%s%s' % (
+                enclosed_by,
+                unicode(value).replace(enclosed_by, escaped_enclosed_by),
+                enclosed_by
+            )
+            if value is not None else '' for value in value_list)
+
+        return delimiter.join(str_value_list) + suffix
+
     def insert_list(self, value_list):
         """
         Insert a ``list`` of values (instead of a ``str`` representing a line).
@@ -415,21 +500,37 @@ class VerticaBatch(object):
             A ``list``. Each item should represent a column value.
 
         """
-        enclosed_by = self.copy_options_dict['ENCLOSED BY']
-        escaped_enclosed_by = '\\%s' % enclosed_by
+        return self.insert_line(self._single_list_to_string(value_list))
 
-        str_value_list = [
-            '%s%s%s' % (
-                enclosed_by,
-                unicode(value).replace(enclosed_by, escaped_enclosed_by),
-                enclosed_by
-            )
-            if value is not None
-            else '' for value in value_list]
+    @require_started_batch
+    def insert_lists(self, value_lists, row_count=1):
+        """
+        Insert an ``iterable`` of ``iterable`` values (instead of a single
+        string). The iterables can be lists, generators, etc.
 
-        insert_str = self.copy_options_dict['DELIMITER'].join(str_value_list)
+        Example::
 
-        return self.insert_line(insert_str)
+            batch.insert_lists([['key1', 'value1'], ['key2', 'value2']))
+
+        :param value_lists:
+            An ``iterable``. Each iterable is another ``iterable`` containing
+            the values to insert.
+
+        :param row_count:
+            An ``int``. The number of rows being inserted. Since the
+            ``value_lists`` parameter may be a generator, the number of
+            rows is not easily determinable. Therefore, the number of
+            rows being inserted must be specified.
+        """
+        suffix = self.copy_options_dict['RECORD TERMINATOR']
+        strings = (self._single_list_to_string(value_list,
+                                               suffix=suffix)
+                   for value_list in value_lists)
+        self._fifo_obj.write(
+            "".join(strings)
+        )
+        self._total_count += row_count
+        self._batch_count += row_count
 
     @require_started_batch
     def insert_line(self, line_str):
@@ -566,7 +667,7 @@ class VerticaBatch(object):
             self._end_batch()
 
         self._connection.commit()
-        logger.info('Transaction comitted, {0} lines inserted'.format(
+        logger.info('Transaction committed, {0} lines inserted'.format(
             batch_count))
 
     def rollback(self):
