@@ -3,14 +3,14 @@
 import os
 import stat
 import tempfile
-import threading
+from taskthread import TaskThread
 import unittest2 as unittest
 from Queue import Queue
 
 from mock import Mock, patch
 
 from pyvertica.batch import (
-    QueryThread, VerticaBatch, require_started_batch)
+    Query, VerticaBatch, require_started_batch)
 
 
 class RequireStartedBatchDecoratorTestCase(unittest.TestCase):
@@ -47,7 +47,7 @@ class RequireStartedBatchDecoratorTestCase(unittest.TestCase):
         self.assertEqual(0, test_class._start_batch.call_count)
 
 
-class QueryThreadTestCase(unittest.TestCase):
+class QueryTestCase(unittest.TestCase):
     """
     Tests for :py:class:`.QueryThread`.
     """
@@ -57,33 +57,28 @@ class QueryThreadTestCase(unittest.TestCase):
         """
         cursor = Mock()
         sql_query_str = Mock()
-        semaphore_obj = Mock()
         fifo_path = Mock()
         exc_queue = Mock()
 
-        query_thread = QueryThread(
-            cursor, sql_query_str, semaphore_obj, fifo_path, exc_queue)
+        query = Query(
+            cursor, sql_query_str, fifo_path, exc_queue)
 
-        self.assertEqual(cursor, query_thread.cursor)
-        self.assertEqual(sql_query_str, query_thread.sql_query_str)
-        self.assertEqual(semaphore_obj, query_thread.semaphore_obj)
-        self.assertEqual(fifo_path, query_thread.fifo_path)
-        self.assertEqual(exc_queue, query_thread.exc_queue)
+        self.assertEqual(cursor, query.cursor)
+        self.assertEqual(sql_query_str, query.sql_query_str)
+        self.assertEqual(fifo_path, query.fifo_path)
+        self.assertEqual(exc_queue, query.exc_queue)
 
-    def test_run(self):
+    def test_run_query(self):
         """
         Test :py:meth:`.QueryThread.run`.
         """
         cursor = Mock()
         sql_query_str = Mock()
-        semaphore_obj = Mock()
 
-        query_thread = QueryThread(
-            cursor, sql_query_str, semaphore_obj, Mock(), Mock())
-        query_thread.run()
+        query = Query(cursor, sql_query_str, Mock(), Mock())
+        query.run_query()
 
         cursor.execute.assert_called_once_with(sql_query_str)
-        semaphore_obj.release.assert_called_once_with()
 
     def test_run_raising_exception(self):
         """
@@ -92,15 +87,17 @@ class QueryThreadTestCase(unittest.TestCase):
         file_obj = tempfile.NamedTemporaryFile(bufsize=0, delete=False)
         file_obj.write('foo\nbar\n')
         file_obj.close()
-        semaphore_obj = threading.Semaphore(0)
 
         cursor = Mock()
-        cursor.execute.side_effect = Exception('Boom!')
+        cursor.execute.side_effect = Exception('boom!')
         exc_queue = Queue()
 
-        QueryThread(
-            cursor, Mock(), semaphore_obj, file_obj.name, exc_queue).start()
-        semaphore_obj.acquire()
+        query = Query(cursor, Mock(), file_obj.name, exc_queue)
+        task_thread = TaskThread(query.run_query)
+        task_thread.start()
+        task_thread.run_task()
+        task_thread.join_task(2)
+        task_thread.join(2)
 
         os.remove(file_obj.name)
         self.assertTrue(isinstance(exc_queue.get(), Exception))
@@ -170,6 +167,31 @@ class VerticaBatchTestCase(unittest.TestCase):
         self.get_batch(truncate_table=True)
         truncate_table.assert_called_once_with()
 
+    def test__init__connection(self):
+        """"
+        Test passing connection to VerticaBatch instead of odbc_kwargs.
+        """
+        connection = Mock()
+        batch = VerticaBatch(table_name='table',
+                             column_list=[],
+                             connection=connection)
+        self.assertEqual(connection, batch._connection)
+        connection.cursor.assert_any_call()
+
+    def test__init__connection_or_odbc_kwargs(self):
+        args = {
+            'odbc_kwargs': {'dsn': 'TestDSN'},
+            'connection': Mock()
+        }
+        try:
+            VerticaBatch(table_name='table',
+                         column_list=[],
+                         odbc_kwargs=args,
+                         connection="connection")
+            self.fail("Should throw ValueError")
+        except ValueError:
+            pass
+
     @patch('pyvertica.batch.get_connection')
     def test_truncate_table(self, get_connection):
         """
@@ -182,22 +204,23 @@ class VerticaBatchTestCase(unittest.TestCase):
         batch._cursor.execute.assert_called_once_with(
             'TRUNCATE TABLE schema.test_table')
 
+    @patch('taskthread.TaskThread')
     @patch('pyvertica.batch.codecs')
     @patch('pyvertica.batch.VerticaBatch._get_sql_lcopy_str')
-    @patch('pyvertica.batch.QueryThread')
-    @patch('pyvertica.batch.threading')
+    @patch('pyvertica.batch.Query')
     @patch('pyvertica.batch.get_connection')
-    def test__start_batch(
-                self,
-                get_connection,
-                threading,
-                QueryThreadMock,
-                get_sql_lcopy_str,
-                codecs,
-            ):
+    def test__start_batch(self,
+                          get_connection,
+                          QueryMock,
+                          get_sql_lcopy_str,
+                          codecs,
+                          TaskThreadMock):
         """
         Test :py:meth:`.VerticaBatch._start_batch`.
         """
+        thread = TaskThreadMock.return_value
+        query = QueryMock.return_value
+        query.run_query = Mock()
         batch = self.get_batch()
         batch._batch_count = 10
 
@@ -211,25 +234,22 @@ class VerticaBatchTestCase(unittest.TestCase):
         self.assertTrue(os.path.exists(batch._rejected_file_obj.name))
         codecs.open.assert_called_once_with(batch._fifo_path, 'w', 'utf-8')
         self.assertEqual(codecs.open.return_value, batch._fifo_obj)
+        self.assertTrue(batch._batch_initialized)
 
         # test thread setup
-        threading.Semaphore.assert_called_once_with(0)
-        self.assertEqual(
-            threading.Semaphore.return_value,
-            batch._query_thread_semaphore_obj
-        )
-        QueryThreadMock.assert_called_once_with(
+        self.assertEqual(thread, batch._query_thread)
+        thread.start.assert_called_once_with()
+
+        QueryMock.assert_called_once_with(
             batch._cursor,
             batch._get_sql_lcopy_str.return_value,
-            batch._query_thread_semaphore_obj,
             batch._fifo_path,
             batch._query_exc_queue,
         )
         self.assertEqual(
-            QueryThreadMock.return_value,
-            batch._query_thread
+            QueryMock.return_value,
+            batch._query
         )
-        batch._query_thread.start.assert_called_once_with()
 
     @patch('pyvertica.batch.os.remove')
     @patch('pyvertica.batch.os.rmdir')
@@ -250,7 +270,6 @@ class VerticaBatchTestCase(unittest.TestCase):
         batch = self.get_batch()
         batch._fifo_path = '/tmp/abcd1234/fifo'
         batch._fifo_obj = Mock()
-        batch._query_thread_semaphore_obj = Mock()
         batch._query_thread = query_thread
         batch._query_exc_queue = Mock()
         batch._query_exc_queue.empty.return_value = True
@@ -258,7 +277,6 @@ class VerticaBatchTestCase(unittest.TestCase):
         end_return = batch._end_batch()
 
         batch._fifo_obj.close.assert_called_once_with()
-        batch._query_thread_semaphore_obj.acquire.assert_called_once_with()
 
         query_thread.join.assert_called_once_with(2)
         query_thread.is_alive.assert_called_once_with()
@@ -287,7 +305,6 @@ class VerticaBatchTestCase(unittest.TestCase):
         batch = self.get_batch()
         batch._fifo_path = '/tmp/abcd1234/fifo'
         batch._fifo_obj = Mock()
-        batch._query_thread_semaphore_obj = Mock()
         batch._query_thread = query_thread
         batch._query_exc_queue = Mock()
         batch._query_exc_queue.empty.return_value = True
@@ -353,6 +370,29 @@ class VerticaBatchTestCase(unittest.TestCase):
 
         self.assertEqual(10, batch._get_num_rejected_rows())
 
+    @patch('pyvertica.batch.get_connection', Mock())
+    def test__single_list_to_string(self):
+        """
+        Test :py:meth:`.VerticaBatch._single_list_to_string`.
+        """
+        batch = self.get_batch()
+        single_list = ['val1', 'val2']
+        expected = u'"val1","val2"'
+        self.assertEqual(expected,
+                         batch._single_list_to_string(single_list))
+
+    @patch('pyvertica.batch.get_connection', Mock())
+    def test__single_list_to_string_suffix(self):
+        """
+        Test :py:meth:`.VerticaBatch._single_list_to_string`.
+        """
+        batch = self.get_batch()
+        single_list = ['val1', 'val2']
+        expected = u'"val1","val2"SUFFIX'
+        self.assertEqual(expected,
+                         batch._single_list_to_string(single_list,
+                                                      suffix='SUFFIX'))
+
     @patch('pyvertica.batch.get_connection')
     def test_insert_list(self, get_connection):
         """
@@ -369,6 +409,26 @@ class VerticaBatchTestCase(unittest.TestCase):
         batch.insert_line.assert_called_once_with(
             u'"valué1","valu\\"e2","None",,"100","value4"')
 
+    @patch('pyvertica.batch.VerticaBatch._start_batch')
+    @patch('pyvertica.batch.get_connection')
+    def test_insert_lists(self, get_connection, start_batch):
+        """
+        Test :py:meth:`.VerticaBatch.insert_lists`.
+        """
+        batch = self.get_batch()
+        batch._fifo_obj = Mock()
+
+        lists = [
+            ['line1value1', "line1value2"],
+            ['line2value1', "line2value2"]
+        ]
+
+        batch.insert_lists(lists, row_count=2)
+        batch._fifo_obj.write.assert_called_once_with(
+            u'"line1value1","line1value2"\x01"line2value1","line2value2"\x01')
+        self.assertEqual(2, batch._total_count)
+        self.assertEqual(2, batch._batch_count)
+
     @patch('pyvertica.batch.VerticaBatch._start_batch')
     @patch('pyvertica.batch.get_connection')
     def test_insert_line(self, get_connection, start_batch):
